BottomBarButton class

Constructors

BottomBarButton({required IconData icon, required String text, required Color foreground_color, required Color background_color, required Widget page})
const

Properties

background_color → Color
final
foreground_color → Color
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
final
page → Widget
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited