DescriptionCard class

Constructors

DescriptionCard({required String image_src, required String title, required String description, required String url, required String url_title, required Color text_color, required Axis direction, required bool reversed, required double current_offset, required double visible_offset})
const

Properties

current_offset → double
final
description → String
final
direction → Axis
final
hashCode → int
The hash code for this object.
no setterinherited
image_src → String
final
reversed → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text_color → Color
final
title → String
final
url → String
final
url_title → String
final
visible_offset → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited