ProgressBar class

Inheritance

Constructors

ProgressBar({required Color color, required Color background_color, required double height, required double parent_width, required double initial_percentage, required double final_percentage, required int animation_delay, required bool show_percentage_text, required double border_radius, required double elevation, required Alignment alignment})
const

Properties

alignment → Alignment
final
animation_delay → int
final
background_color → Color
final
border_radius → double
final
color → Color
final
elevation → double
final
final_percentage → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
initial_percentage → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
parent_width → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show_percentage_text → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ProgressBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited