WhyUsContainer class

Inheritance

Constructors

WhyUsContainer({required List<String> texts, required String background_image, required Color background_color, required IconData characteristic_icon_1, required IconData characteristic_icon_2, required IconData characteristic_icon_3, required Color characteristic_icon_color_1, required Color characteristic_icon_color_2, required Color characteristic_icon_color_3, required Color title_color, required Color subtitle_color})
const

Properties

background_color → Color
final
background_image → String
final
characteristic_icon_1 → IconData
final
characteristic_icon_2 → IconData
final
characteristic_icon_3 → IconData
final
characteristic_icon_color_1 → Color
final
characteristic_icon_color_2 → Color
final
characteristic_icon_color_3 → Color
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle_color → Color
final
texts → List<String>
final
title_color → Color
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _WhyUsContainerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited